@@ -1,7 +1,7 @@
 /*
     KSocrat
-    Version 3.1.2, 28 April 2003
-    (C) 2000-2003 Zavolzhsky Alexandr <zavolzhsky@mail.ru>
+    Version 3.2.1, 17 July 2004
+    (C) 2000-2004 Zavolzhsky Alexandr <zavolzhsky@mail.ru>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,7 +37,6 @@ class DockWidget : public KSystemTray  {
 
   public slots:
     void about();
-    void show_hide();
 };
 
 #endif
